@@ -5,14 +5,10 @@
 import pandas as pd
 import pytest
 import os
-from pytest import mark, param
 from os.path import dirname
 import pandas as pd
-from pandas.io.sql import DatabaseError
 import sys
 import json
-from sqlalchemy import create_engine
-import pymysql
 
 pyinsta_dir = dirname(dirname(__file__))  # This is your Project Root
 root_dir = os.path.realpath(os.path.join(dirname(dirname(__file__)), '..'))
